@@ -15,7 +15,6 @@ Implementation of umath.py, with internals.
 import math
 import sys
 import itertools
-import inspect
 
 # Local modules
 import uncertainties.core as uncert_core
@@ -192,8 +191,8 @@ fixed_derivatives = {
     'cos': [lambda x: -math.sin(x)],
     'cosh': [math.sinh],
     'degrees': [lambda x: math.degrees(1)],
-    'erf': [lambda x: exp(-x**2)*erf_coef],
-    'erfc': [lambda x: -exp(-x**2)*erf_coef],
+    'erf': [lambda x: math.exp(-x**2)*erf_coef],
+    'erfc': [lambda x: -math.exp(-x**2)*erf_coef],
     'exp': [math.exp],
     'expm1': [math.exp],
     'fabs': [_deriv_fabs],
@@ -232,7 +231,7 @@ def wrap_locally_cst_func(func):
         # !! In Python 2.7+, dictionary comprehension: {argname:...}
         kwargs_float = dict(
             (arg_name, uncert_core.nominal_value(value))
-            for (arg_name, value) in iter(kwargs.items()))
+            for (arg_name, value) in kwargs.items())
         return func(*args_float, **kwargs_float)
     return wrapped_func
 
